#!/bin/sh

INSTALL_DIR=`pwd`/install
OPERA_TARGET=mips;
OPERA_TARGET_VER="_R2";

usage()
{
        echo
        echo "Usage: $0 [distclean | clean | configure]"
        echo "  distclean | clean: clean binary and object files"
        echo "  configure: use make configure to configure the compile options."
        echo
}
# create necessary symbolic link for sysconfig.sh. If .config dosn't exist following check fails.
ln -s ../../../../tools/build_tools/.config sysconfig.sh

if [ -e sysconfig.sh ];then
	. sysconfig.sh
	#. config.sh
else
	echo "Openssl not configured for build."
	exit 1;
fi

display_info "---------------------------------------------"
display_info "---------------- OPENSSL --------------------"
display_info "---------------------------------------------"

# check for parameters
if [ $# -lt 1 ]
then
    usage;
    exit 1;
fi

# check if prebuilts are checked out, otherwise skip build
for FILENAME in `ls ./opera/mips_R2/*` ../PreBuilt/mips_R2/WP_COM/ssl_install.tgz ./crypto/opensslconf.h ./crypto/objects/obj_mac.h
do
  if [ ! -w ${FILENAME} ]
  then
    echo "INFO: OpenSSL not rebuilt due to not checked out prebuilts and includes"
    ls -1 ./opera/mips_R2/* ../PreBuilt/mips_R2/WP_COM/ssl_install.tgz ./crypto/opensslconf.h ./crypto/objects/obj_mac.h
    exit 0
  fi
done

rm -f config.sh
parse_args $@
copy_files()
{
	for file in `find . -name '*.VOB'`
	do
		TARGET_FILE=`echo $file | sed "s,.VOB,,"`
		if [ ! -e "$TARGET_FILE" ];then
			cp -f "$file" "$TARGET_FILE"
			chmod ug+rw "$TARGET_FILE"
		fi
	done
}
if [ $BUILD_CLEAN -eq 1 ];then
	if [ "$clean" = "distclean" ];then
		clean="dclean"
	fi
	copy_files
	make $clean
	if [ "$clean" = "dclean" ];then
		find . -name Makefile -exec rm -f '{}' \;
	fi

	if [ $BUILD_CONFIGURE -ne 1 ];then
		exit 0;
	fi	
fi

if [ $BUILD_CONFIGURE -eq 1 ];then
	copy_files
	./Configure shared --install_prefix="$BUILD_ROOTFS_DIR" --prefix=/usr --openssldir=/usr/lib/ssl no-idea no-mdc2 no-rc5 no-krb5 no-perlasm no-hw --openssldir=/usr/lib/ssl linux-mips 
	make depend
fi

echo "Build for "${OPERA_TARGET}${OPERA_TARGET_VER}

make CC="$IFX_CC" AR="$IFX_AR r" AS="$IFX_AS" LD="$IFX_LD" NM="$IFX_NM" STRIP="$IFX_STRIP" RANLIB="$IFX_RANLIB" CXX="$IFX_CXX" CPP="$IFX_CPP" OBJCOPY="$IFX_OBJCOPY" OBJDUMP="$IFX_OBJDUMP" all SHLIB_TARGET=linux-shared build-shared 
RETURN=$?

if [ $RETURN -ne 0 ]
then
    high_light "---------------------------------------------"
    high_light "------ ERROR build failed for OPENSSL -------"
    high_light "------ Try a  "$0" configure "
    high_light "---------------------------------------------"
    exit 1
fi

# Remove sysmbols for size reduction from shared libs
echo "Stripping binaries ..."
for i in `ls  libssl.so* libcrypto.so*`
do
    if [ ! -L $i ]
    then
        SIZE_BEFORE=`ls -l $i | awk '{ printf("%s", $5) }'`
        $IFX_STRIP $i
        SIZE_AFTER=`ls -l $i | awk '{ printf("%s", $5) }'`
        echo "Stripping $i ("$SIZE_BEFORE" => "$SIZE_AFTER")"
    fi
done

# place binary installation in local landing area
rm -rf $INSTALL_DIR
mkdir $INSTALL_DIR
make INSTALL_PREFIX=${INSTALL_DIR} install_sw

#remove files not required and archive
rm -rf ${INSTALL_DIR}/usr/include/openssl/*
PREVIOUS_PATH=`pwd`; cd ${INSTALL_DIR}; tar cvzf ../ssl_install.tgz *; cd ${PREVIOUS_PATH}

# create workpoint specific deploy directory and store libraries/links there
mkdir -p ./opera/${OPERA_TARGET}${OPERA_TARGET_VER}
rm -f ./opera/${OPERA_TARGET}${OPERA_TARGET_VER}/*
tar cvf ssl_shared_libs.tar libssl.so* libcrypto.so*
PREVIOUS_PATH=`pwd`
  cd ./opera/${OPERA_TARGET}${OPERA_TARGET_VER}
  tar xvf ../../ssl_shared_libs.tar
  ln -s libcrypto.so liboperacrypto.so
  ln -s libssl.so liboperassl.so
cd ${PREVIOUS_PATH}

echo
echo "Result will be found in directory ./opera/"${OPERA_TARGET}${OPERA_TARGET_VER}
ls -lR ./opera/${OPERA_TARGET}${OPERA_TARGET_VER}

echo
echo "Save archive ssl_install.tgz in directory ../PreBuilt/"${OPERA_TARGET}${OPERA_TARGET_VER}"/WP_COM"
mkdir -p ../PreBuilt/${OPERA_TARGET}${OPERA_TARGET_VER}/WP_COM
cp ssl_install.tgz ../PreBuilt/${OPERA_TARGET}${OPERA_TARGET_VER}/WP_COM/.

